platform

package
v1.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2025 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ExecutionPlatformMap = make(map[string]string)

Global map to store platform information for each execution

Functions

func GetPlatformConfig

func GetPlatformConfig(platform string, cfg *config.Config) (string, string, string)

func GetPlatformConfigPlain

func GetPlatformConfigPlain(platform string, cfg *config.Config) (string, string)

func GetPlatformForExecution

func GetPlatformForExecution(executionID string) (string, bool)

Function to retrieve platform information for a given execution ID

func SetPlatformForExecution

func SetPlatformForExecution(executionID, platform string)

Types

This section is empty.

Jump to